==> haskell-pcre-heavy-1.0.0.3-42-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pcre-heavy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pcre-heavy
version:              1.0.0.3
visibility:           public
id:                   pcre-heavy-1.0.0.3-LsQfrMqtMxaAsn8IWS4kmV
key:                  pcre-heavy-1.0.0.3-LsQfrMqtMxaAsn8IWS4kmV
license:              LicenseRef-PublicDomain
copyright:            2015-2022 Val Packett <val@packett.cool>
maintainer:           val@packett.cool
author:               Val Packett
homepage:             https://codeberg.org/valpackett/pcre-heavy
synopsis:
    A regexp (regex) library on top of pcre-light you can actually use.

description:
    A regular expressions library that does not suck.
    Based on <https://hackage.haskell.org/package/pcre-light pcre-light>.
    Takes and returns <https://hackage.haskell.org/package/stringable Stringables> everywhere.
    Includes a QuasiQuoter for regexps that does compile time checking.
    SEARCHES FOR MULTIPLE MATCHES! DOES REPLACEMENT!

category:             Web
abi:                  a828b96d8294713f4b8a502658a1a552
exposed:              True
exposed-modules:      Text.Regex.PCRE.Heavy
import-dirs:          /usr/lib/ghc-9.2.8/site-local/pcre-heavy-1.0.0.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/pcre-heavy-1.0.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pcre-heavy
hs-libraries:         HSpcre-heavy-1.0.0.3-LsQfrMqtMxaAsn8IWS4kmV
depends:
    base-4.16.4.0 base-compat-0.12.2-5hQPtIjgG5LKnb20qwjRWd
    bytestring-0.11.4.0 pcre-light-0.4.1.2-3AK1ypQeFer442N3Z3HgOW
    string-conversions-0.4.0.1-D6xKa1tiiemJrtOXoXDyxy
    template-haskell-2.18.0.0

haddock-interfaces:   /usr/share/doc/haskell-pcre-heavy/html/pcre-heavy.haddock
haddock-html:         /usr/share/doc/haskell-pcre-heavy/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pcre-heavy-1.0.0.3-43-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pcre-heavy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pcre-heavy
version:              1.0.0.3
visibility:           public
id:                   pcre-heavy-1.0.0.3-AWtQyGQzzMy8xwJCK0kOCJ
key:                  pcre-heavy-1.0.0.3-AWtQyGQzzMy8xwJCK0kOCJ
license:              LicenseRef-PublicDomain
copyright:            2015-2022 Val Packett <val@packett.cool>
maintainer:           val@packett.cool
author:               Val Packett
homepage:             https://codeberg.org/valpackett/pcre-heavy
synopsis:
    A regexp (regex) library on top of pcre-light you can actually use.

description:
    A regular expressions library that does not suck.
    Based on <https://hackage.haskell.org/package/pcre-light pcre-light>.
    Takes and returns <https://hackage.haskell.org/package/stringable Stringables> everywhere.
    Includes a QuasiQuoter for regexps that does compile time checking.
    SEARCHES FOR MULTIPLE MATCHES! DOES REPLACEMENT!

category:             Web
abi:                  baf5ff2f8e7634937ecf2430321d0aff
exposed:              True
exposed-modules:      Text.Regex.PCRE.Heavy
import-dirs:          /usr/lib/ghc-9.2.8/site-local/pcre-heavy-1.0.0.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/pcre-heavy-1.0.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pcre-heavy
hs-libraries:         HSpcre-heavy-1.0.0.3-AWtQyGQzzMy8xwJCK0kOCJ
depends:
    base-4.16.4.0 base-compat-0.12.2-5hQPtIjgG5LKnb20qwjRWd
    bytestring-0.11.4.0 pcre-light-0.4.1.2-3AK1ypQeFer442N3Z3HgOW
    string-conversions-0.4.0.1-DIhGmAxRazx6IKbU2apUQz
    template-haskell-2.18.0.0

haddock-interfaces:   /usr/share/doc/haskell-pcre-heavy/html/pcre-heavy.haddock
haddock-html:         /usr/share/doc/haskell-pcre-heavy/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
